#!/usr/bin/env python

import glob
import sys
import os
import subprocess
from distutils.core import setup
from distutils.command.install import install

from Genesis import __version__ as VERSION

#Create an array with all the locale filenames
I18NFILES = []
for filepath in glob.glob("locale/*/LC_MESSAGES/*.mo"):
    targetpath = os.path.dirname(os.path.join("share/", filepath))
    I18NFILES.append((targetpath, [filepath]))

ICONTHEMEDIRS = ('/usr/share/icons/hicolor',
                 '/usr/share/icons/Humanity',
                 '/usr/share/icons/Humanity-Dark')

class Install(install):
    def run(self):
        install.run(self)
        print 'Running gtk-update-icon-cache'
        for ICONTHEMEDIR in ICONTHEMEDIRS:
            try:
                subprocess.call(
                    ['gtk-update-icon-cache', '-f', '-t', ICONTHEMEDIR])
            except OSError:
                print 'gtk-update-icon-cache not installed, skipping'
                break

dist = setup(name='genesis',
    version=VERSION,
    author='Frederik Elwert',
    author_email='frederik.elwert@web.de',
    maintainer='Frederik Elwert',
    maintainer_email='frederik.elwert@web.de',
    description='Graphical frontend to SyncEvolution.',
    long_description='Genesis is a graphical frontend for SyncEvolution written in PyGTK. It makes SyncEvolution accessible without having to use a command line and provides graphical feedback of transaction results.',
    url='https://launchpad.net/genesis-sync',
    download_url='https://launchpad.net/genesis-sync/+download',
    license='GNU GPL',
    platforms='linux',
    scripts=['bin/genesis'],
    packages=['Genesis'],
    data_files=[
        ('share/genesis/',
            glob.glob("Genesis/ui/*.ui") + ['Genesis/genesis.spec.ini']),
        ('/usr/share/icons/hicolor/22x22/apps',
            ['icons/hicolor/22/genesis.png']),
        ('/usr/share/icons/hicolor/22x22/status',
            glob.glob('icons/hicolor/22/genesis-*.png')),
        ('/usr/share/icons/hicolor/24x24/apps',
            ['icons/hicolor/24/genesis.png']),
        ('/usr/share/icons/hicolor/24x24/status',
            glob.glob('icons/hicolor/24/genesis-*.png')),
        ('/usr/share/icons/hicolor/scalable/apps',
            ['icons/hicolor/48/genesis.svg']),
        ('/usr/share/icons/hicolor/scalable/status',
            ['icons/hicolor/48/notification-sync-done.svg']),
        ('/usr/share/icons/Humanity/status/22',
            glob.glob('icons/Humanity/22/genesis-*.svg')),
        ('/usr/share/icons/Humanity/status/24',
            glob.glob('icons/Humanity/24/genesis-*.svg')),
        ('/usr/share/icons/Humanity/status/48',
            glob.glob('icons/Humanity/48/notification-sync*.svg')),
        ('/usr/share/icons/Humanity-Dark/status/22',
            glob.glob('icons/Humanity-Dark/22/genesis-*.svg')),
        ('/usr/share/icons/Humanity-Dark/status/24',
            glob.glob('icons/Humanity-Dark/24/genesis-*.svg')),
        ('share/applications', ['bin/genesis.desktop']),
        ] + I18NFILES,
    cmdclass = {'install': Install}
)


